@@ -2,10 +2,11 @@
 __author__ = "Laurent P. René de Cotret"
 __email__ = "laurent.renedecotret@mail.mcgill.ca"
 __license__ = "GPLv3"
-__version__ = "5.2.4"
+__version__ = "5.3.1"
 
 from .raw import AbstractRawDataset, check_raw_bounds, open_raw
-from .dataset import DiffractionDataset, PowderDiffractionDataset
+from .dataset import DiffractionDataset, MigrationWarning, MigrationError
+from .powder import PowderDiffractionDataset
 from .meta import ExperimentalParameter
 from .plugins import install_plugin, load_plugin
 
