@@ -48,10 +48,12 @@ class ProcessedDataViewer(QtWidgets.QWidget):
         )
         self.__dynamics_roi_proxy = pg.SignalProxy(
             self.timeseries_rect_region.sigRegionChanged,
-            rateLimit=60,
+            rateLimit=30,
             slot=self.update_timeseries_rect,
         )
 
+        self.__bragg_peak_items = list()
+
         self.image_viewer.getView().addItem(self.timeseries_rect_region)
         self.timeseries_rect_region.hide()
         self.time_series_widget.hide()
@@ -123,8 +125,8 @@ class ProcessedDataViewer(QtWidgets.QWidget):
         self.roi_bottomright_text.setPos(y2, x2)
         self.roi_bottomright_text.setText(f"({y2},{x2})")
 
-    @QtCore.pyqtSlot(object)
-    def display(self, image):
+    @QtCore.pyqtSlot(object, bool)
+    def display(self, image, autocontrast=False):
         """
         Display an image in the form of an ndarray.
 
@@ -132,22 +134,46 @@ class ProcessedDataViewer(QtWidgets.QWidget):
         ----------
         image : ndarray or None
             If None, the display is cleared.
+        autocontrast: bool, optional
+            If True, the image contrast will be adjusted
         """
         if image is None:
             self.image_viewer.clear()
             return
 
-        # autoLevels = False ensures that the colormap stays the same
-        # when 'sliding' through data. This makes it easier to compare
-        # data at different time points.
-        # Similarly for autoRange = False
-        self.image_viewer.setImage(image, autoLevels=False, autoRange=False)
+        self.image_viewer.setImage(
+            image, autoLevels=autocontrast, autoRange=autocontrast
+        )
         self.update_timeseries_rect()
 
     @QtCore.pyqtSlot(object, object)
     def display_peak_dynamics(self, times, intensities):
-        """ 
-        Display the time series associated with the integral between the bounds 
+        """
+        Display the time series associated with the integral between the bounds
         of the ROI
         """
         self.time_series_widget.plot(times, intensities)
+
+    @QtCore.pyqtSlot(list)
+    def display_bragg_peaks(self, peaks):
+        """
+        Highlight the location of Bragg peaks.
+
+        Parameters
+        ----------
+        peaks : list of 2-tuple
+            List of tuples [row, col] where Bragg peaks are located.
+        """
+        for item in self.__bragg_peak_items:
+            self.image_viewer.removeItem(item)
+        self.__bragg_peak_items.clear()
+
+        for r, c in peaks:
+            self.__bragg_peak_items.append(
+                pg.CircleROI(
+                    pos=(c, r), size=50, movable=False, resizable=False, removable=False
+                )
+            )
+
+        for item in self.__bragg_peak_items:
+            self.image_viewer.addItem(item)
