@@ -107,6 +107,8 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.progress_bar.setSizePolicy(
             QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Maximum
         )
+        self.progress_bar.setVisible(False)
+        self.controller.processing_data_signal.connect(self.progress_bar.setVisible)
 
         self.controller.processing_progress_signal.connect(self.progress_bar.setValue)
         self.controller.powder_promotion_progress.connect(self.progress_bar.setValue)
@@ -146,6 +148,9 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.controller.time_series_signal.connect(
             self.processed_viewer.display_peak_dynamics
         )
+        self.controller.bragg_peaks_signal.connect(
+            self.processed_viewer.display_bragg_peaks
+        )
 
         self.powder_viewer = PowderViewer(parent=self)
         self.powder_viewer.peak_dynamics_roi_signal.connect(
@@ -370,6 +375,12 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
             self.show_diff_relative_action.setEnabled
         )
 
+        self.show_bragg_peaks_action = QtWidgets.QAction("& Show Bragg peaks", self)
+        self.controller.processed_dataset_loaded_signal.connect(
+            self.show_bragg_peaks_action.setEnabled
+        )
+        self.show_bragg_peaks_action.triggered.connect(self.controller.find_bragg_peaks)
+
         self.show_powder_relative_action = QtWidgets.QAction(
             "& Toggle relative dynamics", self
         )
@@ -401,8 +412,8 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.display_options_menu = self.menu_bar.addMenu("&Display")
         self.display_options_menu.addAction(self.toggle_controls_visibility_action)
         self.display_options_menu.addSeparator()
-        self.diffraction_dataset_display_options_menu = self.display_options_menu.addMenu(
-            "& Diffraction display options"
+        self.diffraction_dataset_display_options_menu = (
+            self.display_options_menu.addMenu("& Diffraction display options")
         )
         self.controller.processed_dataset_loaded_signal.connect(
             self.diffraction_dataset_display_options_menu.setEnabled
@@ -425,6 +436,9 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         self.diffraction_dataset_display_options_menu.addAction(
             self.show_diff_relative_action
         )
+        self.diffraction_dataset_display_options_menu.addAction(
+            self.show_bragg_peaks_action
+        )
 
         self.powder_dataset_display_options_menu.addAction(
             self.show_powder_relative_action
@@ -547,10 +561,15 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
         # Otherwise, it doesn't work correctly
         self.load_raw_submenu.clear()
 
-        for rawdatacls in sorted(
-            AbstractRawDataset.implementations, key=lambda c: c.display_name
-        ):
-            self._create_load_raw(rawdatacls, self.load_raw_submenu)
+        if len(AbstractRawDataset.implementations) == 0:
+            act = QtWidgets.QAction("& (no plug-ins installed)", parent=self)
+            act.setEnabled(False)
+            self.load_raw_submenu.addAction(act)
+        else:
+            for rawdatacls in sorted(
+                AbstractRawDataset.implementations, key=lambda c: c.display_name
+            ):
+                self._create_load_raw(rawdatacls, self.load_raw_submenu)
 
     def _create_load_raw(self, cls, submenu):
         submenu.addAction(
@@ -589,6 +608,8 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
             image=self.controller.dataset.diff_data(
                 timedelay=self.controller.dataset.time_points[0]
             ),
+            mask=self.controller.dataset.valid_mask,
+            center=self.controller.dataset.center,
         )
         symmetrize_dialog.resize(0.75 * self.size())
         symmetrize_dialog.symmetrize_parameters_signal.connect(
@@ -612,10 +633,12 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
 
     @QtCore.pyqtSlot()
     def launch_calculate_azimuthal_averages_dialog(self):
-        image = self.controller.dataset.diff_data(
-            self.controller.dataset.time_points[0]
+        promote_dialog = AngularAverageDialog(
+            self.controller.dataset.diff_data(self.controller.dataset.time_points[0]),
+            mask=self.controller.dataset.valid_mask,
+            center=self.controller.dataset.center,
+            parent=self,
         )
-        promote_dialog = AngularAverageDialog(image, parent=self)
         promote_dialog.resize(0.75 * self.size())
         promote_dialog.angular_average_signal.connect(
             self.controller.calculate_azimuthal_averages
@@ -627,10 +650,12 @@ class Iris(QtWidgets.QMainWindow, metaclass=ErrorAware):
 
     @QtCore.pyqtSlot()
     def launch_recompute_angular_average_dialog(self):
-        image = self.controller.dataset.diff_data(
-            self.controller.dataset.time_points[0]
+        dialog = AngularAverageDialog(
+            self.controller.dataset.diff_data(self.controller.dataset.time_points[0]),
+            mask=self.controller.dataset.valid_mask,
+            center=self.controller.dataset.center,
+            parent=self,
         )
-        dialog = AngularAverageDialog(image, parent=self)
         dialog.resize(0.75 * self.size())
         dialog.angular_average_signal.connect(self.controller.recompute_angular_average)
         dialog.exec_()
